@@ -15,7 +15,7 @@
 #include "core/transfergroup.h"
 
 #include "kget_debug.h"
-#include <qdebug.h>
+#include <QDebug>
 
 #include <QDomElement>
 
